@@ -943,7 +943,16 @@ def expose(method_or_class):
             raise AttributeError("exposing private names (starting with _) is not allowed")
         func._pyroExposed = True
         return method_or_class
-    if util.is_private_attribute(method_or_class.__name__):
+    attrname = getattr(method_or_class, "__name__", None)
+    if not attrname:
+        # we could be dealing with a descriptor (classmethod/staticmethod), this means the order of the decorators is wrong
+        if inspect.ismethoddescriptor(method_or_class):
+            attrname = method_or_class.__get__(None, dict).__name__
+            raise AttributeError("using @expose on a classmethod/staticmethod must be done "
+                                 "after @classmethod/@taticmethod. Method: " + attrname)
+        else:
+            raise AttributeError("@expose cannot determine what this is: "+repr(method_or_class))
+    if util.is_private_attribute(attrname):
         raise AttributeError("exposing private names (starting with _) is not allowed")
     if inspect.isclass(method_or_class):
         clazz = method_or_class
@@ -1022,7 +1031,9 @@ class DaemonObject(object):
                 # Something seems wrong: nothing is remotely exposed.
                 # Possibly because older code not using @expose is now running with a more recent Pyro version
                 # where @expose is mandatory in the default configuration. Give a hint to the user.
-                warnings.warn("Class %r doesn't expose any methods or attributes. Did you forget setting @expose on them?" % type(obj))
+                if not inspect.isclass(obj):
+                    obj = type(obj)
+                warnings.warn("Class %r doesn't expose any methods or attributes. Did you forget setting @expose on them?" % obj)
             return metadata
         else:
             log.debug("unknown object requested: %s", objectId)
@@ -1550,7 +1561,10 @@ class Daemon(object):
             # register a custom serializer for the type to automatically return proxies
             # we need to do this for all known serializers
             for ser in util._serializers.values():
-                ser.register_type_replacement(type(obj_or_class), pyroObjectToAutoProxy)
+                if inspect.isclass(obj_or_class):
+                    ser.register_type_replacement(obj_or_class, pyroObjectToAutoProxy)
+                else:
+                    ser.register_type_replacement(type(obj_or_class), pyroObjectToAutoProxy)
         # register the object/class in the mapping
         self.objectsById[obj_or_class._pyroId] = obj_or_class
         return self.uriFor(objectId)
@@ -1791,6 +1805,20 @@ class _CallContext(threading.local):
         self.correlation_id = values["correlation_id"]
         self.client_sock_addr = values["client_sock_addr"]
 
+    def track_resource(self, resource):
+        """keep a weak reference to the resource to be tracked for this connection"""
+        if self.client:
+            self.client.tracked_resources.add(resource)
+        else:
+            raise errors.PyroError("cannot track resource on a connectionless call")
+
+    def untrack_resource(self, resource):
+        """no longer track the resource for this connection"""
+        if self.client:
+            self.client.tracked_resources.discard(resource)
+        else:
+            raise errors.PyroError("cannot untrack resource on a connectionless call")
+
 
 class _OnewayCallThread(threading.Thread):
     def __init__(self, target, args, kwargs):
