@@ -6,15 +6,15 @@ Flame requires the pickle serializer to be used.
 Pyro - Python Remote Objects.  Copyright by Irmen de Jong (irmen@razorvine.net).
 """
 
+from __future__ import print_function
 import sys
 import types
 import code
 import os
 import stat
-import Pyro4.core
-import Pyro4.util
-import Pyro4.constants
-import Pyro4.errors
+from Pyro4 import constants, errors, core
+from Pyro4.configuration import config
+
 
 try:
     import importlib
@@ -65,13 +65,13 @@ class FlameModule(object):
 
     def __init__(self, flameserver, module):
         # store a proxy to the flameserver regardless of autoproxy setting
-        self.flameserver = Pyro4.core.Proxy(flameserver._pyroDaemon.uriFor(flameserver))
+        self.flameserver = core.Proxy(flameserver._pyroDaemon.uriFor(flameserver))
         self.module = module
 
     def __getattr__(self, item):
         if item in ("__getnewargs__", "__getnewargs_ex__", "__getinitargs__"):
             raise AttributeError(item)
-        return Pyro4.core._RemoteMethod(self.__invoke, "%s.%s" % (self.module, item), 0)
+        return core._RemoteMethod(self.__invoke, "%s.%s" % (self.module, item), 0)
 
     def __getstate__(self):
         return self.__dict__
@@ -98,7 +98,7 @@ class FlameBuiltin(object):
 
     def __init__(self, flameserver, builtin):
         # store a proxy to the flameserver regardless of autoproxy setting
-        self.flameserver = Pyro4.core.Proxy(flameserver._pyroDaemon.uriFor(flameserver))
+        self.flameserver = core.Proxy(flameserver._pyroDaemon.uriFor(flameserver))
         self.builtin = builtin
 
     def __call__(self, *args, **kwargs):
@@ -133,7 +133,7 @@ class RemoteInteractiveConsole(object):
 
     def __init__(self, remoteconsoleuri):
         # store a proxy to the console regardless of autoproxy setting
-        self.remoteconsole = Pyro4.core.Proxy(remoteconsoleuri)
+        self.remoteconsole = core.Proxy(remoteconsoleuri)
 
     def interact(self):
         console = self.LineSendingConsole(self.remoteconsole)
@@ -158,7 +158,7 @@ class RemoteInteractiveConsole(object):
         self.close()
 
 
-@Pyro4.expose
+@core.expose
 class InteractiveConsole(code.InteractiveConsole):
     """Interactive console wrapper that saves output written to stdout so it can be returned as value"""
 
@@ -185,16 +185,16 @@ class InteractiveConsole(code.InteractiveConsole):
         self.resetbuffer()
 
 
-@Pyro4.expose
+@core.expose
 class Flame(object):
     """
     The actual FLAME server logic.
-    Usually created by using :py:meth:`Pyro4.core.Daemon.startFlame`.
+    Usually created by using :py:meth:`core.Daemon.startFlame`.
     Be *very* cautious before starting this: it allows the clients full access to everything on your system.
     """
 
     def __init__(self):
-        if set(Pyro4.config.SERIALIZERS_ACCEPTED) != {"pickle"}:
+        if set(config.SERIALIZERS_ACCEPTED) != {"pickle"}:
             raise RuntimeError("flame requires the pickle serializer exclusively")
 
     def module(self, name):
@@ -249,11 +249,11 @@ class Flame(object):
         console.banner = "Python %s on %s\n(Remote console on %s)" % (sys.version, sys.platform, uri.location)
         return RemoteInteractiveConsole(uri)
 
-    @Pyro4.expose
+    @core.expose
     def invokeBuiltin(self, builtin, args, kwargs):
         return getattr(builtins, builtin)(*args, **kwargs)
 
-    @Pyro4.expose
+    @core.expose
     def invokeModule(self, dottedname, args, kwargs):
         # dottedname is something like "os.path.walk" so strip off the module name
         modulename, dottedname = dottedname.split('.', 1)
@@ -300,21 +300,23 @@ def start(daemon):
     Create and register a Flame server in the given daemon.
     Be *very* cautious before starting this: it allows the clients full access to everything on your system.
     """
-    if Pyro4.config.FLAME_ENABLED:
-        if set(Pyro4.config.SERIALIZERS_ACCEPTED) != {"pickle"}:
-            raise Pyro4.errors.SerializeError("Flame requires the pickle serializer exclusively")
-        return daemon.register(Flame(), Pyro4.constants.FLAME_NAME)
+    if config.FLAME_ENABLED:
+        if set(config.SERIALIZERS_ACCEPTED) != {"pickle"}:
+            raise errors.SerializeError("Flame requires the pickle serializer exclusively")
+        return daemon.register(Flame(), constants.FLAME_NAME)
     else:
-        raise Pyro4.errors.SecurityError("Flame is disabled in the server configuration")
+        raise errors.SecurityError("Flame is disabled in the server configuration")
 
 
-def connect(location):
+def connect(location, hmac_key=None):
     """
     Connect to a Flame server on the given location, for instance localhost:9999 or ./u:unixsock
     This is just a convenience function to creates an appropriate Pyro proxy.
     """
-    if Pyro4.config.SERIALIZER != "pickle":
-        raise Pyro4.errors.SerializeError("Flame requires the pickle serializer")
-    proxy = Pyro4.core.Proxy("PYRO:%s@%s" % (Pyro4.constants.FLAME_NAME, location))
+    if config.SERIALIZER != "pickle":
+        raise errors.SerializeError("Flame requires the pickle serializer")
+    proxy = core.Proxy("PYRO:%s@%s" % (constants.FLAME_NAME, location))
+    if hmac_key:
+        proxy._pyroHmacKey = hmac_key
     proxy._pyroBind()
     return proxy
